@@ -2,7 +2,9 @@
 from __future__ import absolute_import
 import hashlib
 
-def signature(secret_key, params, hash_secret=True):
+ENCODING = 'cp1251'
+
+def signature(secret_key, params, hash_secret=True, encoding=ENCODING):
     """
     Calculates money.mail.ru signature for the params dict.
     Pass hash_secret = True for signing outgoing requests
@@ -14,10 +16,10 @@ def signature(secret_key, params, hash_secret=True):
 
     sorted_keys = sorted(key for key in params if key != 'signature')
     if hash_secret:
-        key_bytes = secret_key.encode('cp1251')
+        key_bytes = secret_key.encode(encoding)
         secret_hash = hashlib.sha1(key_bytes).hexdigest().encode('ascii')
     else:
         secret_hash = secret_key.encode('ascii')
-    values = [params[key].encode('cp1251') for key in sorted_keys] + [secret_hash]
+    values = [params[key].encode(encoding) for key in sorted_keys] + [secret_hash]
     sig_string = b"".join(values)
     return hashlib.sha1(sig_string).hexdigest()
